package pps.core.prediction.service;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.date.DateTime;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.text.CharSequenceUtil;
import com.alibaba.fastjson2.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import pps.cloud.base.service.BasePhotovoltaicPlantCloudService;
import pps.cloud.base.service.IBaseEnergyStorageCloudService;
import pps.cloud.base.service.IBasePowerLineCloudService;
import pps.cloud.base.service.IBaseWellheadCloudService;
import pps.cloud.base.service.data.base_energy_storage_device.DynamicQueryBaseEnergyStorageDeviceInput;
import pps.cloud.base.service.data.base_energy_storage_device.DynamicQueryBaseEnergyStorageDeviceOutput;
import pps.cloud.base.service.data.base_photovoltaic_plant.GetBasePhotovoltaicPlantCloudInput;
import pps.cloud.base.service.data.base_photovoltaic_plant.GetBasePhotovoltaicPlantCloudOutput;
import pps.cloud.base.service.data.base_power_line.DynamicQueryBasePowerLineInput;
import pps.cloud.base.service.data.base_power_line.DynamicQueryBasePowerLineOutput;
import pps.cloud.base.service.data.base_wellhead.DynamicQueryBaseWellheadInput;
import pps.cloud.base.service.data.base_wellhead.DynamicQueryBaseWellheadOutput;
import pps.cloud.system.service.SysOrganizationCloudService;
import pps.cloud.system.service.data.GetAllOuListByOuIdInput;
import pps.cloud.system.service.data.GetSysOrganizationViewOutput;
import pps.core.common.constant.BusinessConstant;
import pps.core.prediction.constant.ThirdPartyApiConstant;
import pps.core.prediction.entity.EnergyConsumptionAnalysisEnt;
import pps.core.prediction.entity.PredictedPowerView;
import pps.core.prediction.entity.ThirdActivePowerDailyUpdateView;
import pps.core.prediction.enums.BusinessError;
import pps.core.prediction.mapper.EnergyConsumptionAnalysisMapper;
import pps.core.prediction.mapper.PredictedPowerViewMapper;
import pps.core.prediction.mapper.ThirdActivePowerDailyUpdateViewMapper;
import pps.core.prediction.service.data.energy_consumption_analysis.DynamicQueryEnergyConsumptionAnalysisViewOutput;
import pps.core.prediction.service.data.energy_consumption_analysis.QueryEnergyConsumptionAnalysisInput;
import pps.core.prediction.service.data.home_page.*;
import pps.core.prediction.service.data.third_current_well_condition.GetThirdCurrentWellConditionViewOutput;
import pps.core.prediction.service.data.third_photovoltaic_power.GetCumulativePowerGenerationOutput;
import pps.core.prediction.utils.ServiceUtil;
import xstartup.annotation.XService;
import xstartup.annotation.XText;
import xstartup.base.XContext;
import xstartup.data.XListResult;
import xstartup.data.XSingleResult;
import xstartup.feature.api.annotation.XApiAnonymous;
import xstartup.feature.api.annotation.XApiGet;

import java.math.BigDecimal;
import java.math.RoundingMode;
import java.util.*;
import java.util.function.Function;
import java.util.stream.Collectors;

/**
 * 首页
 *
 * @author ZWT
 * @date 2024/03/25 17:54
 */
@XText("首页模块")
@XService
public class HomePageService {

    /**
     * 首页模块--井场列表
     *
     * @param context 上下文
     * @param input   输入
     * @return {@link XListResult}<{@link GetStationViewOutput}>
     */
    @XText("首页模块--井场列表")
    @XApiGet
    public XListResult<GetStationViewOutput> getStationList(XContext context, GetStationViewInput input) {
        List<GetStationViewOutput> outputs;
        String stationId = input.getStationId();
        if (CharSequenceUtil.isBlank(stationId)) {
            //查组织
            SysOrganizationCloudService service = context.getBean(SysOrganizationCloudService.class);
            XListResult<GetSysOrganizationViewOutput> result = service.getPlantList(context);
            result.throwIfFail();
            outputs = new ArrayList<>(result.getResult().size());
            result.getResult().forEach(item -> {
                outputs.add(GetStationViewOutput.builder()
                        .stationId(item.getId())
                        .stationName(item.getOuName())
                        .longitude(item.getLongitude())
                        .latitude(item.getLatitude())
                        .build());
            });
        } else {
            //查电站
            List<GetBasePhotovoltaicPlantCloudOutput> plantList = this.getPlantList(context, stationId);
            outputs = new ArrayList<>(plantList.size());
            plantList.forEach(item -> {
                GetStationViewOutput output = new GetStationViewOutput();
                output.setStationId(item.getId());
                output.setStationName(item.getStationName());
                outputs.add(GetStationViewOutput.builder()
                        .stationId(item.getId())
                        .stationName(item.getStationName())
                        .longitude(item.getLongitude())
                        .latitude(item.getLatitude())
                        .build());
            });
        }
        return XListResult.success(outputs);
    }

    /**
     * 首页模块--总览
     *
     * @param context 上下文
     * @param input   输入
     * @return {@link XSingleResult}<{@link GetOverviewViewOutput}>
     */
    @XText("首页模块--总览")
    @XApiGet
    public XSingleResult<GetOverviewViewOutput> getOverview(XContext context, GetStationViewInput input) {
        String stationId = input.getStationId();
        List<DynamicQueryBaseWellheadOutput> wellList = this.getWellList(context, stationId);
        List<GetBasePhotovoltaicPlantCloudOutput> plantList = this.getPlantList(context, stationId);
        List<DynamicQueryBasePowerLineOutput> lineList = this.getLineList(context, stationId, "10");
        List<DynamicQueryBaseEnergyStorageDeviceOutput> storageList = this.getStorageList(context, stationId);
        return XSingleResult.success(GetOverviewViewOutput.builder()
                .wellNumber(wellList.size())
                .stationNumber(plantList.size())
                .lineNumber(lineList.size())
                .operatingLoad(wellList.stream()
                        .map(DynamicQueryBaseWellheadOutput::getRatedPower)
                        .reduce(BigDecimal.ZERO, BigDecimal::add))
                .photovoltaicPower(plantList.stream()
                        .map(GetBasePhotovoltaicPlantCloudOutput::getTotalPower)
                        .reduce(BigDecimal.ZERO, BigDecimal::add))
                .storagePower(storageList.stream()
                        .map(DynamicQueryBaseEnergyStorageDeviceOutput::getApparatusCapacity)
                        .reduce(BigDecimal.ZERO, BigDecimal::add))
                .build());
    }

    /**
     * 首页模块--井场实时监控
     *
     * @param context 上下文
     * @param input   输入
     * @return {@link XSingleResult}<{@link GetWellOverviewViewOutput}>
     */
    @XText("首页模块--井场实时监控")
    @XApiGet
    public XSingleResult<GetWellOverviewViewOutput> getWellOverview(XContext context, GetStationViewInput input) {
        String stationId = input.getStationId();
        int openWellNumber = 0;
        int stopWellNumber = 0;
        BigDecimal cumulativeProduction = BigDecimal.ZERO;
        BigDecimal powerGeneration = BigDecimal.ZERO;
        BigDecimal powerConsumption = BigDecimal.ZERO;
        try {
            //实时井口
            String wellResult = ServiceUtil.doPostFormCq(context,
                    ThirdPartyApiConstant.CQ_WELL_REAL_PV_DATA,
                    new HashMap<>(0));
            List<GetThirdCurrentWellConditionViewOutput> wellList = JSON.parseArray(wellResult, GetThirdCurrentWellConditionViewOutput.class);
            if (CollUtil.isNotEmpty(wellList)) {
                Set<String> set = this.getWellList(context, stationId).stream()
                        .map(DynamicQueryBaseWellheadOutput::getWellNumber)
                        .collect(Collectors.toSet());
                for (GetThirdCurrentWellConditionViewOutput well : wellList) {
                    if (set.contains(well.getWellNumber())) {
                        if (CharSequenceUtil.equals(well.getWellStatus(), "开井")) {
                            openWellNumber++;
                        } else {
                            stopWellNumber++;
                        }
                    }
                }
            }
            //实时站
            String stationResult = ServiceUtil.doPostFormCq(context,
                    ThirdPartyApiConstant.CQ_GROUP_REAL_PV_DATA,
                    new HashMap<>(0));
            List<GetCumulativePowerGenerationOutput> stationList = JSON.parseArray(stationResult, GetCumulativePowerGenerationOutput.class);
            if (CollUtil.isNotEmpty(stationList)) {
                Set<String> set = this.getPlantList(context, stationId).stream()
                        .map(GetBasePhotovoltaicPlantCloudOutput::getStationName)
                        .collect(Collectors.toSet());
                for (GetCumulativePowerGenerationOutput station : stationList) {
                    if (set.contains(station.getStationName())) {
                        cumulativeProduction = cumulativeProduction.add(station.getDailyLiquidProduction());
                        powerGeneration = powerGeneration.add(station.getPhotovoltaicPower());
                        powerConsumption = powerConsumption.add(station.getDailyElectricityConsumption());
                    }
                }
            }
        } catch (Exception e) {
            context.getLogger().error(e);
        }
        return XSingleResult.success(GetWellOverviewViewOutput.builder()
                .openWellNumber(openWellNumber)
                .stopWellNumber(stopWellNumber)
                .cumulativeProduction(cumulativeProduction)
                .powerGeneration(powerGeneration)
                .powerConsumption(powerConsumption)
                .build());
    }

    /**
     * 首页模块--用能分析
     *
     * @param context 上下文
     * @param input   输入
     * @return {@link XListResult}<{@link DynamicQueryEnergyConsumptionAnalysisViewOutput}>
     */
    @XText("首页模块--用能分析")
    @XApiGet
    public XListResult<DynamicQueryEnergyConsumptionAnalysisViewOutput> getPowerAnalyse(XContext context, GetStationViewInput input) {
        String stationId = Optional.ofNullable(input.getStationId())
                .orElse("446285aa-ac58-435e-84af-19fc62a8267f");
        EnergyConsumptionAnalysisService service = context.getBean(EnergyConsumptionAnalysisService.class);
        return service.queryEnergyConsumptionAnalysisList(context, QueryEnergyConsumptionAnalysisInput.builder()
                .ouId(stationId)
                .dateType(1)
                .build());
    }

    /**
     * 累积用电
     *
     * @param context 上下文
     * @param input   输入
     * @return {@link XSingleResult}<{@link GetSumPowerConsumptionOutput}>
     */
    @XText("首页模块--累积用电")
    @XApiGet
    public XSingleResult<GetSumPowerConsumptionOutput> getSumPowerConsumption(XContext context, GetStationViewInput input) {
        String stationId = input.getStationId();
        DateTime startTime = DateUtil.beginOfDay(DateUtil.yesterday());
        List<GetStationPowerConsumption> stationList;
        BigDecimal powerConsumption = BigDecimal.ZERO;
        EnergyConsumptionAnalysisMapper mapper = context.getBean(EnergyConsumptionAnalysisMapper.class);
        if (CharSequenceUtil.isBlank(stationId)) {
            stationId = "446285aa-ac58-435e-84af-19fc62a8267f";
            Map<String, String> collect = this.getOrgIdsByPath(context, stationId).stream()
                    .collect(Collectors.toMap(GetSysOrganizationViewOutput::getId, GetSysOrganizationViewOutput::getOuName));
            Map<String, List<DynamicQueryBasePowerLineOutput>> listMap = this.getBasePowerLineListByOuIdList(context, collect.keySet()).stream()
                    .collect(Collectors.groupingBy(DynamicQueryBasePowerLineOutput::getOuId));
            stationList = new ArrayList<>(4);
            for (Map.Entry<String, List<DynamicQueryBasePowerLineOutput>> entry : listMap.entrySet()) {
                List<String> lineIdList = entry.getValue().stream()
                        .map(DynamicQueryBasePowerLineOutput::getId)
                        .collect(Collectors.toList());
                EnergyConsumptionAnalysisEnt ent = mapper.selectOne(new QueryWrapper<EnergyConsumptionAnalysisEnt>()
                        .select("IFNULL( SUM( power_consumption ), 0 ) AS power_consumption")
                        .lambda()
                        .in(EnergyConsumptionAnalysisEnt::getLineId, lineIdList)
                        .eq(EnergyConsumptionAnalysisEnt::getDataDate, startTime)
                );
                stationList.add(GetStationPowerConsumption.builder()
                        .stationName(collect.get(entry.getKey()))
                        .powerConsumption(ent.getPowerConsumption())
                        .build());
                powerConsumption = powerConsumption.add(ent.getPowerConsumption());
            }
        } else {
            List<String> lineIdList = this.getBasePowerLineListByOuIdList(context, CollUtil.list(false, stationId)).stream().map(DynamicQueryBasePowerLineOutput::getId).collect(Collectors.toList());
            List<EnergyConsumptionAnalysisEnt> list = mapper.selectList(new QueryWrapper<EnergyConsumptionAnalysisEnt>()
                    .select("IFNULL( SUM( power_consumption ), 0 ) AS power_consumption", "station_name")
                    .lambda()
                    .in(EnergyConsumptionAnalysisEnt::getLineId, lineIdList)
                    .eq(EnergyConsumptionAnalysisEnt::getDataDate, startTime)
                    .groupBy(EnergyConsumptionAnalysisEnt::getStationName)
            );
            stationList = new ArrayList<>(list.size());
            for (EnergyConsumptionAnalysisEnt ent : list) {
                stationList.add(GetStationPowerConsumption.builder()
                        .stationName(ent.getStationName())
                        .powerConsumption(ent.getPowerConsumption())
                        .build());
                powerConsumption = powerConsumption.add(ent.getPowerConsumption());
            }
        }
        return XSingleResult.success(GetSumPowerConsumptionOutput.builder()
                .powerConsumption(powerConsumption)
                .stationList(stationList)
                .build());
    }

    /**
     * 光伏实时监控
     *
     * @param context 上下文
     * @param input   输入
     * @return {@link XSingleResult}<{@link GetPowerPredictionOutput}>
     */
    @XText("首页模块--光伏实时监控")
    @XApiGet
    public XListResult<GetPowerPredictionOutput> getPowerPrediction(XContext context, GetStationViewInput input) {
        String plantId = input.getPlantId();
        List<GetBasePhotovoltaicPlantCloudOutput> plantList;
        List<String> plantIds = null;
        if (CharSequenceUtil.isNotBlank(plantId)) {
            input.setStationId(null);
        } else {
            plantList = this.getPlantList(context, input.getStationId());
            plantIds = plantList.stream().map(GetBasePhotovoltaicPlantCloudOutput::getId).collect(Collectors.toList());
            if (CollUtil.isEmpty(plantIds)) {
                plantIds = null;
            }
        }
        DateTime day = DateUtil.beginOfDay(DateUtil.date());
        //预测发电量
        PredictedPowerViewMapper mapper = context.getBean(PredictedPowerViewMapper.class);
        Map<String, BigDecimal> shortPowerMap = mapper.selectShortPowerHourList(PredictedPowerView.builder()
                        .createTime(day)
                        .plantIds(plantIds)
                        .plantId(plantId)
                        .build()).stream()
                .collect(Collectors.toMap(PredictedPowerView::getHourTime, PredictedPowerView::getPower));
        //实时数据
        ThirdActivePowerDailyUpdateViewMapper nowMapper = context.getBean(ThirdActivePowerDailyUpdateViewMapper.class);
        Map<Integer, ThirdActivePowerDailyUpdateView> powerMap = nowMapper.selectEnergyUseCurve(ThirdActivePowerDailyUpdateView.builder()
                        .stationIds(plantIds)
                        .stationId(plantId)
                        .saveDate(day)
                        .build()).stream()
                .collect(Collectors.toMap(ThirdActivePowerDailyUpdateView::getHourNumber, Function.identity()));
        List<GetPowerPredictionOutput> outputs = new ArrayList<>(24);
        ThirdActivePowerDailyUpdateView powerDaily;
        for (int i = 0; i < 24; i++) {
            BigDecimal predictPower = BigDecimal.ZERO;
            BigDecimal actualPower = BigDecimal.ZERO;
            BigDecimal meterPower = BigDecimal.ZERO;
            String value = String.valueOf(i);
            if (shortPowerMap.containsKey(value)) {
                predictPower = shortPowerMap.get(value);
            }
            if (powerMap.containsKey(i)) {
                powerDaily = powerMap.get(i);
                actualPower = powerDaily.getPhotovoltaicPower();
                meterPower = powerDaily.getMeterPower();
            }
            outputs.add(
                    GetPowerPredictionOutput.builder()
                            .hourNumber(i)
                            .predictPower(predictPower)
                            .actualPower(actualPower)
                            .meterPower(meterPower)
                            .build()
            );
        }
        return XListResult.success(outputs);
    }

    /**
     * 收益分析
     *
     * @param context 上下文
     * @param input   输入
     * @return {@link XSingleResult}<{@link GetIncomeAnalysisOutput}>
     */
    @XText("首页模块--收益分析")
    @XApiGet
    public XSingleResult<GetIncomeAnalysisOutput> getIncomeAnalysis(XContext context, GetStationViewInput input) {
        String stationId = input.getStationId();
        List<String> lineIdList = this.getLineList(context, stationId, null).stream()
                .map(DynamicQueryBasePowerLineOutput::getId)
                .collect(Collectors.toList());
        DateTime yesterday = DateUtil.beginOfDay(DateUtil.yesterday());
        EnergyConsumptionAnalysisMapper mapper = context.getBean(EnergyConsumptionAnalysisMapper.class);
        EnergyConsumptionAnalysisEnt analysisEnt = mapper.selectOne(new QueryWrapper<EnergyConsumptionAnalysisEnt>()
                .select("IFNULL( SUM( power_generation ), 0 ) AS power_generation",
                        "IFNULL( SUM( power_consumption ), 0 ) AS power_consumption")
                .lambda()
                .in(EnergyConsumptionAnalysisEnt::getLineId, lineIdList)
                .eq(EnergyConsumptionAnalysisEnt::getDataDate, yesterday)
        );
        //发电量
        BigDecimal powerGeneration = analysisEnt.getPowerGeneration()
                .setScale(2, BigDecimal.ROUND_HALF_UP);
        //累计减碳量
        BigDecimal carbonReduction = analysisEnt.getPowerGeneration()
                .multiply(BigDecimal.valueOf(6.67))
                .divide(BigDecimal.valueOf(10000), 2, RoundingMode.HALF_UP);
        //经济效益
        BigDecimal economicBenefit = analysisEnt.getPowerGeneration()
                .multiply(BigDecimal.valueOf(0.6))
                .subtract(analysisEnt.getPowerGeneration()
                        .multiply(BigDecimal.valueOf(0.28)))
                .setScale(2, BigDecimal.ROUND_HALF_UP);
        //绿电占比
        BigDecimal greenElectricityRate = this.getAbsorptionRate(analysisEnt.getPowerGeneration(), analysisEnt.getPowerConsumption());
        BigDecimal bigDecimal = new BigDecimal(100);
        if (greenElectricityRate.compareTo(bigDecimal) > 0) {
            greenElectricityRate = bigDecimal;
        }
        return XSingleResult.success(GetIncomeAnalysisOutput.builder()
                .absorptionRate(BigDecimal.valueOf(100))
                .avoidPeakRate(BigDecimal.valueOf(100))
                .energyStorageCapacity(BigDecimal.ZERO)
                .powerGeneration(powerGeneration)
                .greenElectricityRate(greenElectricityRate)
                .carbonReduction(carbonReduction)
                .economicBenefit(economicBenefit)
                .build());
    }

    /**
     * 采油厂详情
     *
     * @param context 上下文
     * @param input   输入
     * @return {@link XSingleResult}<{@link GetOilExtractionPlantOutput}>
     */
    @XApiAnonymous
    @XText("首页模块--采油厂详情")
    @XApiGet
    public XSingleResult<GetOilExtractionPlantOutput> getOilExtractionPlantInfo(XContext context, GetStationViewInput input) {
        String stationId = input.getStationId();
        if (CharSequenceUtil.isBlank(stationId)) {
            return XSingleResult.error(context, BusinessError.MissingoilExtractionPlantID);
        }
        Integer intervalWellNumber = 0;
        Integer continuousWellNumber = 0;
        BigDecimal operatingLoad = BigDecimal.ZERO;
        //井口统计
        List<DynamicQueryBaseWellheadOutput> wellList = this.getWellList(context, stationId);
        for (DynamicQueryBaseWellheadOutput well : wellList) {
            if (CharSequenceUtil.equals(BusinessConstant.CONTINUOUS_PUMPING_WELL, well.getRunTypeKey())) {
                continuousWellNumber++;
            } else {
                intervalWellNumber++;
            }
            operatingLoad = operatingLoad.add(well.getRatedPower());
        }
        //线路统计
        List<DynamicQueryBasePowerLineOutput> lineList = this.getLineList(context, stationId, "10");
        //光伏电站
        List<GetBasePhotovoltaicPlantCloudOutput> plantList = this.getPlantList(context, stationId);
        //储能电站
        List<DynamicQueryBaseEnergyStorageDeviceOutput> storageList = this.getStorageList(context, stationId);
        return XSingleResult.success(GetOilExtractionPlantOutput.builder()
                .wellNumber(wellList.size())
                .intervalWellNumber(intervalWellNumber)
                .continuousWellNumber(continuousWellNumber)
                .operatingLoad(operatingLoad)
                .lineNumber(lineList.size())
                .photovoltaicPower(plantList.stream()
                        .map(GetBasePhotovoltaicPlantCloudOutput::getTotalPower)
                        .reduce(BigDecimal.ZERO, BigDecimal::add))
                .storagePower(storageList.stream()
                        .map(DynamicQueryBaseEnergyStorageDeviceOutput::getApparatusCapacity)
                        .reduce(BigDecimal.ZERO, BigDecimal::add))
                .build());
    }

    /**
     * 线路图
     *
     * @param context 上下文
     * @param input   输入
     * @return {@link XListResult}<{@link GetBranchingProgramOutput}>
     */
    @XApiAnonymous
    @XText("首页模块--线路图")
    @XApiGet
    public XListResult<GetBranchingProgramOutput> getBranchingProgram(XContext context, GetStationViewInput input) {
        String stationId = input.getStationId();
        if (CharSequenceUtil.isBlank(stationId)) {
            return XListResult.error(context, BusinessError.MissingoilExtractionPlantID);
        }
        //十千伏线路
        List<DynamicQueryBasePowerLineOutput> lineList = this.getLineList(context, stationId, "10");
        List<GetBranchingProgramOutput> outputs = new ArrayList<>(lineList.size());
        for (DynamicQueryBasePowerLineOutput line : lineList) {
            outputs.add(GetBranchingProgramOutput.builder()
                    .mainLineId(line.getId())
                    .mainLineName(line.getLineName())
                    .subLineList(this.getSubLineList(context, line.getId()))
                    .build());
        }
        return XListResult.success(outputs);
    }

    

    /*------------------------------------------------- private ---------------------------------------------------------*/

    /**
     * 获取消纳率
     * 消纳率:光伏发电/累计用电*100%
     *
     * @param powerGeneration  发电
     * @param powerConsumption 功耗
     * @return {@link BigDecimal}
     */
    private BigDecimal getAbsorptionRate(BigDecimal powerGeneration, BigDecimal powerConsumption) {
        BigDecimal absorptionRate;
        if (powerConsumption.compareTo(BigDecimal.ZERO) > 0) {
            absorptionRate = powerGeneration.divide(powerConsumption, 4, RoundingMode.HALF_UP)
                    .multiply(new BigDecimal(100));
        } else {
            absorptionRate = BigDecimal.ZERO;
        }
        return absorptionRate;
    }

    /**
     * 查询组织列表下所有线路
     *
     * @param context  上下文
     * @param ouIdList ou-id列表
     * @return {@link List}<{@link DynamicQueryBasePowerLineOutput}>
     */
    private List<DynamicQueryBasePowerLineOutput> getBasePowerLineListByOuIdList(XContext context, Collection<String> ouIdList) {
        IBasePowerLineCloudService basePowerLineCloudService = context.getBean(IBasePowerLineCloudService.class);
        XListResult<DynamicQueryBasePowerLineOutput> lineList = basePowerLineCloudService.getBasePowerLineListByOuIdList(context, DynamicQueryBasePowerLineInput.builder()
                .ouIdList(ouIdList)
                .build());
        lineList.throwIfFail();
        return lineList.getResult();
    }

    /**
     * 获取所有path包含组织ID的组织
     *
     * @param context 上下文
     * @param ouId    ou id
     * @return {@link List}<{@link GetSysOrganizationViewOutput}>
     */
    private List<GetSysOrganizationViewOutput> getOrgIdsByPath(XContext context, String ouId) {
        SysOrganizationCloudService organizationCloudService = context.getBean(SysOrganizationCloudService.class);
        GetAllOuListByOuIdInput ouIdInput = new GetAllOuListByOuIdInput();
        ouIdInput.setOuId(ouId);
        XListResult<GetSysOrganizationViewOutput> allListByOuId = organizationCloudService.getAllListByOuId(context, ouIdInput);
        allListByOuId.throwIfFail();
        return allListByOuId.getResult();
    }

    /**
     * 获取井口列表
     *
     * @param context   上下文
     * @param stationId 工作站id
     * @return {@link List}<{@link DynamicQueryBaseWellheadOutput}>
     */
    private List<DynamicQueryBaseWellheadOutput> getWellList(XContext context, String stationId) {
        IBaseWellheadCloudService service = context.getBean(IBaseWellheadCloudService.class);
        XListResult<DynamicQueryBaseWellheadOutput> result = service.queryBaseWellheadListByParam(context, DynamicQueryBaseWellheadInput.builder()
                .ouId(stationId)
                .build());
        result.throwIfFail();
        return result.getResult();
    }

    /**
     * 光伏电站列表
     *
     * @param context   上下文
     * @param stationId 工作站id
     * @return {@link List}<{@link GetBasePhotovoltaicPlantCloudOutput}>
     */
    private List<GetBasePhotovoltaicPlantCloudOutput> getPlantList(XContext context, String stationId) {
        BasePhotovoltaicPlantCloudService service = context.getBean(BasePhotovoltaicPlantCloudService.class);
        XListResult<GetBasePhotovoltaicPlantCloudOutput> result = service.getBasePhotovoltaicPlantList(context, GetBasePhotovoltaicPlantCloudInput.builder()
                .ouId(stationId)
                .build());
        result.throwIfFail();
        return result.getResult();
    }

    /**
     * 输电线路列表
     *
     * @param context     上下文
     * @param stationId   工作站id
     * @param lineTypeKey 线型键
     * @return {@link List}<{@link DynamicQueryBasePowerLineOutput}>
     */
    private List<DynamicQueryBasePowerLineOutput> getLineList(XContext context, String stationId, String lineTypeKey) {
        IBasePowerLineCloudService service = context.getBean(IBasePowerLineCloudService.class);
        XListResult<DynamicQueryBasePowerLineOutput> result = service.getBasePowerLineList(context, DynamicQueryBasePowerLineInput.builder()
                .ouId(stationId)
                .lineTypeKey(lineTypeKey)
                .build());
        result.throwIfFail();
        return result.getResult();
    }

    /**
     * 获取子线路列表
     *
     * @param context     上下文
     * @param upperLineId 上级线路ID
     * @return {@link List}<{@link DynamicQueryBasePowerLineOutput}>
     */
    private List<DynamicQueryBasePowerLineOutput> getSubLineList(XContext context, String upperLineId) {
        IBasePowerLineCloudService service = context.getBean(IBasePowerLineCloudService.class);
        XListResult<DynamicQueryBasePowerLineOutput> result = service.getBasePowerLineList(context, DynamicQueryBasePowerLineInput.builder()
                .upperLineId(upperLineId)
                .build());
        result.throwIfFail();
        return result.getResult();
    }

    /**
     * 获取储能列表
     *
     * @param context   上下文
     * @param stationId 工作站id
     * @return {@link List}<{@link DynamicQueryBaseEnergyStorageDeviceOutput}>
     */
    private List<DynamicQueryBaseEnergyStorageDeviceOutput> getStorageList(XContext context, String stationId) {
        IBaseEnergyStorageCloudService service = context.getBean(IBaseEnergyStorageCloudService.class);
        XListResult<DynamicQueryBaseEnergyStorageDeviceOutput> result = service.queryBaseStorageListByParam(context, DynamicQueryBaseEnergyStorageDeviceInput.builder()
                .ouId(stationId)
                .build());
        result.throwIfFail();
        return result.getResult();
    }
}